﻿using System.Collections.Generic;
using UnityEngine;
using System.IO;
using System;
using UnityEngine.UI;
//using Excel = Microsoft.Office.Interop.Excel;

public class IO : MonoBehaviour
{
    [SerializeField] Slider mySlider;
    [SerializeField] Text myTextBox;
    [SerializeField] Line myLine;
    [SerializeField] Dropdown myDropdown;
    GameObject[] gos;
    [SerializeField] string currentStudy = "Example";
    [SerializeField] bool inToggle = true;
    [SerializeField] bool outToggle = true;

    public double GetSliderValue()
    {
        float sliderValue = mySlider.value;
        double rValue = 0.5 + (sliderValue * 0.05);
        return rValue;
    }

    public void UpdateInToggle()
    {
        inToggle = !inToggle;
        LoadHeightsSerialized();
    }

    public void UpdateOutToggle()
    {
        outToggle = !outToggle;
        LoadHeightsSerialized();
    }


    public bool GetInToggle()
    {
        return inToggle;
    }

    public bool GetOutToggle()
    {
        return outToggle;
    }

    // Start is called before the first frame update
    void Start()
    {
        
    }


    

    public void UpdateSlider()
    {
        
        UpdateRPrintout();
        LoadHeightsSerialized();
        
    }

    public void UpdateDrowpdownStudy()
    {

        int dropValue = myDropdown.value;
        string dropText = myDropdown.options[dropValue].text;
        currentStudy = dropText;

    }

    public void ZeroTowerHeights()
    {
        GameObject[] towers;
        towers = GameObject.FindGameObjectsWithTag("tower");
        foreach (GameObject tower in towers)
        {
            Tower t = tower.GetComponent<Tower>();
            t.setHeight(0);
        }
    }

    public void updateSelectedMetabolite(string name, float Zscore)
    {
        string text = "Selected Metabolite:\n " + name + "\n Z-score: " + String.Format("{0:0.00}", Zscore);
        myTextBox.text = text;
        Debug.Log(name + Zscore);
    }

    public void UpdateRPrintout()
    {
        float sliderValue = mySlider.value;
        double rValue = 0.5 + (sliderValue * 0.05);
        GameObject.Find("RText").GetComponent<Text>().text = "R>= " + rValue.ToString();
    }

    public void LoadHeightsSerialized()
    {
        ZeroTowerHeights();
        float sliderValue = mySlider.value;
        double rValue = 0.5 + (sliderValue * 0.05);

        string fileName = "Assets/Data/" + currentStudy + "/heights_" + rValue.ToString("0.00") + ".json";
        if (inToggle == true & outToggle == false) {
            fileName = "Assets/Data/" + currentStudy + "/INheights_" + rValue.ToString("0.00") + ".json";
        }
        else if (inToggle == false & outToggle == true)
        {
            fileName = "Assets/Data/" + currentStudy + "/OUTheights_" + rValue.ToString("0.00") + ".json";
        }
        else if (inToggle == false & outToggle == false)
        {
            ZeroTowerHeights();
            return;
        }
        
        string jsonString = File.ReadAllText(fileName);
        //Debug.Log(fileName);
        Heights heights = JsonUtility.FromJson<Heights>(jsonString);
        foreach (TowerHeight th in heights.heights)
        {
            string metaboliteID = th.ID;
            float caseHeight = th.case_height;
            float controlHeight = th.control_height;


            GameObject caseTower;
            GameObject controlTower;

            caseTower = GameObject.Find("Case/Towers/Tower_" + metaboliteID);
            controlTower = GameObject.Find("Control/Towers/Tower_" + metaboliteID);

            if (caseTower != null)
            {
                Tower t = caseTower.GetComponent<Tower>();
                t.setHeight(caseHeight);
            }

            if (controlTower != null)
            {
                Tower t = controlTower.GetComponent<Tower>();
                t.setHeight(controlHeight);
            }
        }
    }

    

    public void LoadZScoresSerialized()
    {
        // A faster method for loading metabolites - from json
        float offset = transform.position.x;
        string jsonString = File.ReadAllText("Assets/Data/" + currentStudy + "/zscores.json");
        ZScores zscores = JsonUtility.FromJson<ZScores>(jsonString);
        foreach (ZScore z in zscores.zscores)
        {

            string metaboliteID = z.ID;
            float zscore = z.zscore;
            GameObject caseMetabolite;
            GameObject controlMetabolite;

            caseMetabolite = GameObject.Find("Case/Metabolites/" + metaboliteID);
            controlMetabolite = GameObject.Find("Control/Metabolites/" + metaboliteID);
            //Debug.Log(metaboliteName);
            if (metaboliteID != "") {

                if (caseMetabolite != null)
                {
                    Metabolite m = caseMetabolite.GetComponent<Metabolite>();
                    m.setZscore(zscore);
                }
                else
                {
                    Debug.Log("error" + metaboliteID);
                }

                if (controlMetabolite != null)
                {
                    Metabolite m = controlMetabolite.GetComponent<Metabolite>();
                    m.setZscore(zscore);
                }
                else
                {
                    Debug.Log("error" + metaboliteID);
                }
            }
        }
    }

    
    public void LoadExample()
    {
        LoadLines();
        LoadZScoresSerialized();
        LoadHeightsSerialized();
    }

    public void LoadLines()
    {
        Landscape[] landscapes = FindObjectsOfType<Landscape>();
        foreach (Landscape landscape in landscapes)
        {
            landscape.LoadLinesSerialized(currentStudy);
        }
    }



    // Update is called once per fram
    void Update()
    {
        
    }
}
