﻿using System.Collections;
using System.Collections.Generic;
using System.Xml.Schema;
using UnityEngine;
using System.IO;
using JetBrains.Annotations;
using System;

public class Landscape : MonoBehaviour
{
    [SerializeField] Metabolite myMetabolite;
    [SerializeField] Tower myTower;
    [SerializeField] Line myLine;

    
    // Start is called before the first frame update
    void Start()
    {


        AddMetabolitesSerialized();
        AddTowersSerialized();
        
    }



    public void AddTowersSerialized()
    {
        // A faster method for loading metabolites - from json
        //string type = transform.name;
        float offset = transform.position.x;
        string jsonString = File.ReadAllText("Assets/Data/Setup/metabolites_for_unity.json");
        Metabolites mets = JsonUtility.FromJson<Metabolites>(jsonString);
        foreach (MetaboliteObj met in mets.metabolites)
        {
            float x = met.x;
            float y = met.y;
            float z = met.z;
            string id = met.ID;
            string name = met.name;
            Tower newTower = Instantiate(myTower, new Vector3(x + offset, y, z), transform.rotation) as Tower;
            newTower.transform.parent = transform.GetChild(2);
            //newMetabolite.transform.localPosition = new Vector3(x, 0, y);
            newTower.name = "Tower_" + id;
            float zscore = 0f;
            newTower.setHeight(zscore);

            // ADD NEGATIVE TOWERS:
            Tower newTowerNeg = Instantiate(myTower, new Vector3(x + offset, y, z), transform.rotation) as Tower;
            newTowerNeg.transform.parent = transform.GetChild(2);
            //newMetabolite.transform.localPosition = new Vector3(x, 0, y);
            newTowerNeg.name = "Tower_NEG_" + id;
            newTower.setHeight(zscore);

        }
    }


    public void AddMetabolitesSerialized()
    {
        // A faster method for loading metabolites - from json
        //string type = transform.name;
        float offset = transform.position.x;
        string jsonString = File.ReadAllText("Assets/Data/Setup/metabolites_for_unity.json");
        Metabolites mets = JsonUtility.FromJson<Metabolites>(jsonString);
        foreach (MetaboliteObj met in mets.metabolites)
        {
            float x = met.x;
            float y = met.y;
            float z = met.z;
            string id = met.ID;
            string name = met.name;
            Metabolite newMetabolite = Instantiate(myMetabolite, new Vector3(x + offset, y, z), transform.rotation) as Metabolite;
            newMetabolite.transform.parent = transform.GetChild(1);
            //newMetabolite.transform.localPosition = new Vector3(x, 0, y);
            newMetabolite.name = id;
            newMetabolite.setID(id);
            newMetabolite.setName(name);
            float zscore = 0f;
            newMetabolite.setZscore(zscore);
        }
    }

    

    // Update is called once per frame
    void Update()
    {
    
    }

    public void LoadLinesSerialized(string studyName)
    {
        string type = transform.name;
        float offset = transform.position.x;
        string jsonString = File.ReadAllText("Assets/Data/" + studyName + "/"+ type + "_lines.json");
        MyLines los = JsonUtility.FromJson<MyLines>(jsonString);
        foreach (MyLine line in los.lines)
        {
            Line newLine = Instantiate(myLine, new Vector3(0, 0, 0), transform.rotation) as Line;
            newLine.transform.parent = transform.GetChild(3);
            LineRenderer lineRenderer = newLine.GetComponent<LineRenderer>();
            lineRenderer.SetPosition(0, new Vector3(line.from[0] + offset, line.from[1]+10, line.from[2]));
            lineRenderer.SetPosition(1, new Vector3(line.to[0] + offset, line.to[1]+10, line.to[2]));
            newLine.name = line.name;
            newLine.SetRValue(line.rvalue);
            newLine.SetPwyInOut(line.pwy);
        }

    }

    
}


